@@ -1,7 +1,7 @@
 package Bb::Collaborate::Ultra::SessionEnrollment;
 use warnings; use strict;
 use Mouse;
-extends 'Bb::Collaborate::Ultra';
+extends 'Bb::Collaborate::Ultra::DAO';
 __PACKAGE__->resource('enrollments');
 __PACKAGE__->load_schema(<DATA>);
 
@@ -9,6 +9,10 @@ __PACKAGE__->load_schema(<DATA>);
 
 Bb::Collaborate::Ultra::SessionEnrollment - Session enrollments
 
+=head2 METHODS
+
+See L<https://xx-csa.bbcollab.com/documentation#SessionEnrollment>
+
 =cut
 
 # downloaded from https://xx-csa.bbcollab.com/documentation
